package com.ruoyi.mall.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.mall.domain.MallAcceptRule;
import com.ruoyi.mall.domain.Vo.CountRuleVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 录取原则Service接口
 *
 * @author Lsm
 * @date 2023-10-18
 */
public interface IMallAcceptRuleService
{
    /**
     * 查询录取原则
     *
     * @param acceptRuleId 录取原则主键
     * @return 录取原则
     */
    public MallAcceptRule selectMallAcceptRuleByAcceptRuleId(Long acceptRuleId);

    /**
     * 查询录取原则列表
     *
     * @param mallAcceptRule 录取原则
     * @return 录取原则集合
     */
    public List<MallAcceptRule> selectMallAcceptRuleList(MallAcceptRule mallAcceptRule);

    /**
     * 新增录取原则
     *
     * @param mallAcceptRule 录取原则
     * @return 结果
     */
    public AjaxResult insertMallAcceptRule(MallAcceptRule mallAcceptRule);

    /**
     * 修改录取原则
     *
     * @param mallAcceptRule 录取原则
     * @return 结果
     */
    public int updateMallAcceptRule(MallAcceptRule mallAcceptRule);

    /**
     * 批量删除录取原则
     *
     * @param acceptRuleIds 需要删除的录取原则主键集合
     * @return 结果
     */
    public int deleteMallAcceptRuleByAcceptRuleIds(Long[] acceptRuleIds);

    /**
     * 删除录取原则信息
     *
     * @param acceptRuleId 录取原则主键
     * @return 结果
     */
    public int deleteMallAcceptRuleByAcceptRuleId(Long acceptRuleId);

    /**
     * 录取原则列表
     * @param ruleClass 类别(0-本科,1-专科)
     * @return 结果
     */
    public List<CountRuleVO> selectNewAcceptRuleList(Long ruleClass);
}
